Learn R Programming

sgee (version 0.6-2)

deltaValue: deltaValue

Description

Function to calculate an update under a given configuration.

Usage

deltaValue(a, lambda1, lambda2, gamma)

Value

The form of a group update for given lambda1, lambda2, and gamma.

Arguments

a

Subvector of Estimating Equations that pertains to a particular group.

lambda1

Tuning parameter pertaining to importance of groups.

lambda2

Tuning parameter pertaining to importance of individuals.

gamma

Scaling / thresholding value.

Author

Gregory Vaughan

Details

Internal function used by bisee.